==> qcm-debug-1.0.2-6-x86_64.pkg.tar.zst: usr/src/debug/qcm/Qcm/app/main.cpp <==
#include <QGuiApplication>
#include <QQmlApplicationEngine>
#include <QCommandLineParser>
#include <QSurfaceFormat>
#include <QLoggingCategory>

#include "Qcm/app.h"
#include "request/request.h"
#include "core/log.h"

#include <QtQml/QQmlExtensionPlugin>
Q_IMPORT_QML_PLUGIN(Qcm_AppPlugin)
Q_IMPORT_QML_PLUGIN(Qcm_MaterialPlugin)

#include <kdsingleapplication.h>

int main(int argc, char* argv[]) {
    auto logger = qcm::LogManager::init();
    request::global_init();

    QGuiApplication gui_app(argc, argv);

    QCoreApplication::setApplicationName(APP_NAME);
    QCoreApplication::setApplicationVersion(APP_VERSION);

    QCommandLineParser parser;
    {
        parser.addHelpOption();
        parser.addVersionOption();
        QCommandLineOption verboseOption("verbose");
        parser.addOption(verboseOption);
        parser.process(gui_app);

        logger->set_level(parser.isSet(verboseOption) ? qcm::LogLevel::DEBUG : qcm::LogLevel::WARN);
        QLoggingCategory::setFilterRules(
            QString::fromStdString(fmt::format("qcm.debug={}", parser.isSet(verboseOption))));
    }

    KDSingleApplication single;
    if (! single.isPrimaryInstance()) {
        WARN_LOG("another qcm running, triggering");
        single.sendMessageWithTimeout("hello", 5);
        exit(0);
    }
    // QSurfaceFormat format;
    // format.setSamples(4);
    // QSurfaceFormat::setDefaultFormat(format);

    int re { 0 };
    {
        qcm::App app;
        QObject::connect(&single, &KDSingleApplication::messageReceived, app.instance(), []() {
            emit qcm::App::instance()->instanceStarted();
        });
        app.init();

        re = gui_app.exec();
    }

    return re;
}

==> qcm-debug-1.0.3-2-x86_64.pkg.tar.zst: usr/src/debug/qcm/Qcm/app/main.cpp <==
#include <QGuiApplication>
#include <QQmlApplicationEngine>
#include <QCommandLineParser>
#include <QSurfaceFormat>
#include <QLoggingCategory>

#include "Qcm/app.h"
#include "request/request.h"
#include "core/log.h"

#include <QtQml/QQmlExtensionPlugin>
Q_IMPORT_QML_PLUGIN(Qcm_AppPlugin)
Q_IMPORT_QML_PLUGIN(Qcm_MaterialPlugin)

#include <kdsingleapplication.h>

int main(int argc, char* argv[]) {
    auto logger = qcm::LogManager::init();
    request::global_init();

    QGuiApplication gui_app(argc, argv);

    QCoreApplication::setApplicationName(APP_NAME);
    QCoreApplication::setApplicationVersion(APP_VERSION);

    QCommandLineParser parser;
    {
        parser.addHelpOption();
        parser.addVersionOption();
        QCommandLineOption verboseOption("verbose");
        parser.addOption(verboseOption);
        parser.process(gui_app);

        logger->set_level(parser.isSet(verboseOption) ? qcm::LogLevel::DEBUG : qcm::LogLevel::WARN);
        QLoggingCategory::setFilterRules(
            QLatin1String(fmt::format("qcm.debug={}", parser.isSet(verboseOption))));
    }

    KDSingleApplication single;
    if (! single.isPrimaryInstance()) {
        WARN_LOG("another qcm running, triggering");
        single.sendMessageWithTimeout("hello", 5);
        exit(0);
    }
    // QSurfaceFormat format;
    // format.setSamples(4);
    // QSurfaceFormat::setDefaultFormat(format);

    int re { 0 };
    {
        qcm::App app;
        QObject::connect(&single, &KDSingleApplication::messageReceived, app.instance(), []() {
            emit qcm::App::instance()->instanceStarted();
        });
        app.init();

        re = gui_app.exec();
    }

    return re;
}
